PyCoordTopocentric
==================

.. currentmodule:: cysgp4

.. autoclass:: PyCoordTopocentric
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~PyCoordTopocentric.az
      ~PyCoordTopocentric.dist
      ~PyCoordTopocentric.dist_rate
      ~PyCoordTopocentric.el

   .. rubric:: Attributes Documentation

   .. autoattribute:: az
   .. autoattribute:: dist
   .. autoattribute:: dist_rate
   .. autoattribute:: el
